==> haskell-css-text-0.1.3.0-379-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-3L2qsEGORmS2v4gPCRD1A3
key:                  css-text-0.1.3.0-3L2qsEGORmS2v4gPCRD1A3
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  bd3d16beb065815723bf220d291b2993
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-3L2qsEGORmS2v4gPCRD1A3
depends:
    attoparsec-0.14.4-4euoXrooDbuLZe6Xn3rp2d base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-380-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-8J6qtXipCls2bMfu5UpzAK
key:                  css-text-0.1.3.0-8J6qtXipCls2bMfu5UpzAK
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  3fc9e949587eac5f8e28d14cf1660709
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-8J6qtXipCls2bMfu5UpzAK
depends:
    attoparsec-0.14.4-IjP3u1baQ7d7AdktrTB8o9 base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
